!************************************************************
!QUARTA VERSO DO PROGRAMA PARA CLCULO DO CD	(03/07/2015)
!BASEADA NOS RELATRIOS DE C.P. HOULT, NISKANEN E CANNON
!AUTOR: TOBIAS PINHEIRO QUELUZ
!************************************************************
PROGRAM Coeficiente_de_arrasto

!EXTERNAL Cd_atrito, Cd_base, Nariz_geometria, Area_laminar, Cd_tuboguia, PORTLIB 

USE PORTLIB

!DEFINIO DAS VARIVEIS

INTEGER motorligado, Na, Nt, It, i, U 

REAL*8 To, Po, Retc, Rete, M, Pi, L, Swet, Dc, Sw, Sref, Cf, Cfl, Cft, C, Cdac, &
       Le, Cdae, Cfe, Cfle, Cfte, Swete, e, Rc, Tc, S, VER, N, Cda, Cdbc, Cdbe, Cdb, &
	   Dt, St, Lna, Dna, Lc, Swetc, Swetna, Cdtb, Detb, Ditb, Ltb, Cbc, Cdpe, Cdi, &
       etb, Mmax, Cd, Sc, Sa, Cdpn, Soma, Cdm, V
       
REAL*8 To1, Po1

CHARACTER (50) SAIDA, TEXTO, TEXTO1, TEXTO2

!CHAMADA DO ARQUIVO DE ENTRADA

VER = SYSTEM('Notepad dados.txt')

OPEN(1, file = 'dados.txt')

READ(1,*) SAIDA                    !Nome do arquivo de sada

!CONSTANTES FSICAS
READ(1,*) U                        !Unidade utilizada nas medidas do foguete (1=milmetros, 2=ps, 3=polegadas)
READ(1,*) To1                      !Temperatura atmosfrica (C)
READ(1,*) Po1                      !Presso atmosfrica (kPa)
READ(1,*) Retc                     !Nmero de Reynolds de transio para corpos de revoluo
READ(1,*) Rete	                   !Nmero de Reynolds de transio para empenas
READ(1,*) Mmax                     !Nmero de mach mximo
READ(1,*) It                       !Nmero de pontos do grfico
To   = (To1+273.15d0)*9d0/5d0      !Temperatura atmosfrica absoluta (deg R)
Po   = Po1*20.885434273d0          !Presso atmosfrica (lb/ft)
Pi   = dacos(-1d0)                 !Nmero de Pi

!GEOMETRIA DO NARIZ
READ(1,*) Na                       !Tipo de nariz (1=elpsoide, 2=ogiva, 3=cnico, 4=parablico)
READ(1,*) Lna                      !Comprimento total do corpo (mm)
READ(1,*) Dna                      !Dimetro do corpo (mm)

!GEOMETRIA DO TUBO-FOGUETE
READ(1,*) Lc                       !Comprimento do tubo (mm)
READ(1,*) Dc                       !Dimetro do tubo (mm)

!GEOMETRIA DA EMPENA
READ(1,*) N                        !Nmero de empenas
READ(1,*) Ac                       !Acabamento da empena(o=quadrado, 1=arredondado)
READ(1,*) e                        !Espessura (mm)
READ(1,*) Rc                       !Comprimento da base (mm)
READ(1,*) Tc                       !Comprimento do topo (mm)
READ(1,*) S                        !Altura (mm)
READ(1,*) Sc                       !Comprimento do contorno (mm)

!GEOMETRIA DO MOTOR
READ(1,*) motorligado	           !Condio do motor (ligado/desligado)
READ(1,*) Dt                       !Dimetro da tubeira (mm)

!GEOMETRIA DO TUBO-GUIA
READ(1,*) Nt                       !Presena de tubo-guia (1=sim, 0=no)
READ(1,*) Detb                     !Dimetro externo do tubo-guia (mm)
READ(1,*) etb                      !Espessura do tubo-guia (mm)
READ(1,*) Ltb                      !Comprimento do tubo-guia (mm)

CLOSE(1)

!CONVERSO DE UNIDADES
SELECT CASE (U)
    
CASE(1) !Milmetros
    
CASE(2) !Ps para milmetros
    CALL pes(Lna, Dna, Lc, Dc, e, Rc, Tc, S, Sc, Dt, Detb, etb, Ltb)
    
CASE(3) !Polegadas para milmetros
    CALL polegadas(Lna, Dna, Lc, Dc, e, Rc, Tc, S, Sc, Dt, Detb, etb, Ltb)
    
END SELECT   

!GEOMETRIA CALCULADA

!Nariz
CALL Narizgeo (Pi, Na, Lna, Dna, Swetna)    !rea do nariz em contato com o ar (mm)

!Tubo-foguete
Swetc = Pi*Dc*Lc                            !rea do tubo em contato com o ar (mm)

!Corpo
L   = Lna + Lc                              !Comprimento total do corpo (mm) 
Swet = Swetna + Swetc                       !rea em contato com o ar (mm)
Sref = Pi*Dc**2d0/4d0                       !rea de referncia (igual  seo tranversal do corpo) (mm)

!Empena
Sa = datan(Sc/S)                            !ngulo do contorno (rad)
Swete = (Rc+Tc)*S                           !rea em contato com o ar (mm)
Le = (Rc+Tc)/2d0                            !Comprimento mdio da empena (mm)
    
!Motor
St = Pi*Dt**2d0/4d0	                        !rea de sada dos gases (mm)
    
!tubo-guia
Ditb = Detb - 2d0*etb                       !Dimetro interno do tubo-guia (mm)


!GRAVAO DOS COEFICIENTES DE ARRASTO
TEXTO1 = 'Curva1_'//SAIDA
TEXTO2 = 'Curva_trajetria_'//SAIDA
OPEN(7, file=TEXTO1)
OPEN(9, file=TEXTO2)
WRITE(7,*) " # Nmero de Mach            V(km/h)           Coeficiente de arrasto"
TEXTO1 = "Notepad "//TEXTO1
TEXTO2 = "Notepad "//TEXTO2
Soma = 0d0

DO i= 1, It, 1
    
    M = (Mmax/(It*1d0))*(i*1d0)
    V = M*1224d0
    
    !COEFICIENTE DE ARRASTO DE ATRITO
    CALL CdAtritoc (To,Po,Retc,M,Cf,Swet,Cfl,Cft,C,L,Sref, Cdac, Pi, Lna, Dna, Na, Swetna, Dc)
    CALL CdAtritoe (To,Po,Rete,M,Cfe,Swete,Cfle,Cfte,C,Le,Sref, Cdae, N)
    Cda = Cdac + Cdae   !Coeficiente de arrasto de atrito total


    !COEFICIENTE DE ARRASTO DE BASE
    CALL Cdbasec (Sref, Pi, Dc, Cdbc, St, M, motorligado, Cbc, Cda, Cf)
    CALL Cdbasee (N, e, S, Sref, Cfe, Cdbe)
    
    Cdb = Cdbc      !Coeficiente de arrasto de atrito total
    !Cdb = Cdbc +Cdbe    !Coeficiente de arrasto de atrito total

    !COEFICIENTE DE ARRASTO DO TUBO-GUIA
    CALL Cdtubo (Pi, Detb, Ditb, Ltb, Sref, Cdtb, Nt, M, Swetc)


    !COEFICIENTE DE ARRASTO DE PRESSO
    CALL Cdpressaoe(M, Tc, S, Cbc, N, e, Sref, Cdpe, Sa)
    CALL Cdpressaon(M, Na, Dna, Lna, Cdpn)
    
    Cdp = Cdpe + Cdpn

    !COEFICIENTE DE ARRASTO DE INTERFERNCIA
    CALL Cdinterferencia(Cfe, e, Le, Tc, Dc, N, Sref, Cdi) 


    !COEFICIENTE DE ARRASTO TOTAL
    Cd = (Cda+Cdb+Cdtb+Cdp+Cdi)*1.05
   
    !CLCULO DO CD MDIO
    Soma = Cd + Soma
    Cdm = Soma/i
    
    WRITE(7,*) M, V, Cd
    WRITE(9,*) V, Cd
    
END DO

CLOSE(7)
CLOSE(9)

VER = SYSTEM(TEXTO1)
VER = SYSTEM(TEXTO2)

!SADA DOS RESULTADOS

OPEN(8,file=SAIDA)

WRITE(8,*)"COEFICIENTE DE ARRASTO PARA MACHI =", Mmax
WRITE(8,*)""
WRITE(8,*)"Coeficiente de arrasto de atrito:", Cda
WRITE(8,*)""
WRITE(8,*)"Coeficiente de arrasto de base:", Cdb
WRITE(8,*)""
WRITE(8,*)"Coeficiente de arrasto do tubo-guia:", CdTb
WRITE(8,*)""
WRITE(8,*)"Coeficiente de arrasto de presso:", Cdp
WRITE(8,*)""
WRITE(8,*)"Coeficiente de arrasto de interferncia:", Cdi
WRITE(8,*)""
WRITE(8,*)""
WRITE(8,*)"COEFICIENTE DE ARRASTO TOTAL:", Cd
WRITE(8,*)""
WRITE(8,*)"COEFICIENTE DE ARRASTO MDIO:", Cdm


CLOSE(8)

TEXTO = "Notepad "//SAIDA

VER = System(TEXTO)

END PROGRAM Coeficiente_de_arrasto
